import React, { useState, useEffect, useRef, ReactNode } from 'react';
import styles from './dropdowns.module.scss';
import Icon from '../icon';
import { ArrowDropDown } from '@mui/icons-material';
import { PopoverContent, PopoverTrigger, Popover } from '../layout/Popover';

export const DropdownContainer = Popover;

type DropdownTriggerProps = {
  title: string | ReactNode;
  size?: 'xs' | 'sm' | 'md' | 'xl';
  disabled?: boolean;
  variant?: 'primary' | 'ghost' | 'outline';
  className?: string;
  onClick?: () => void;
};

export function DropdownTrigger({ title, size, disabled, variant, className, onClick }: DropdownTriggerProps) {
  const paddingClass = size === 'xs' ? 'py-0' : size === 'sm' ? 'px-1 py-1' : size === 'md' ? 'px-2 py-1' : 'px-4 py-2';
  const textSizeClass = size === 'xs' ? 'text-xs' : size === 'sm' ? 'text-sm' : size === 'md' ? 'text-base' : 'text-lg';

  const variantClass =
    variant === 'primary' || !variant
      ? 'border bg-light rounded'
      : variant === 'ghost'
        ? 'bg-transparent shadow-none'
        : 'border rounded bg-transparent';
  return (
    <PopoverTrigger onClick={onClick}>
      <div
        className={`inline-flex w-full truncate justify-between items-center gap-x-1.5 ${variantClass} ${textSizeClass} ${paddingClass} text-secondary-900 shadow-sm hover:bg-secondary-50 disabled:bg-secondary-100 disabled:cursor-not-allowed disabled:text-secondary-400 pl-1 truncate${className ? ` ${className}` : ''}`}
      >
        <span className={`text-${size}`}>{title}</span>
        <Icon component={<ArrowDropDown />} size={16} />
      </div>
    </PopoverTrigger>
  );
}

type DropdownItemContainerProps = {
  // align: string;
  className?: string;
  children: ReactNode;
};

export const DropdownItemContainer = React.forwardRef<HTMLDivElement, DropdownItemContainerProps>(({ children, className }, ref) => {
  return (
    <PopoverContent
      ref={ref}
      className={`${styles['dropdown-container']} ${className} bg-light`}
      role="menu"
      aria-orientation="vertical"
      aria-labelledby="menu-button"
      tabIndex={-1}
    >
      <ul role="none">{children}</ul>
    </PopoverContent>
  );
});

type DropdownItemProps = {
  value: string;
  disabled?: boolean;
  className?: string;
  onClick?: (value: string) => void;
  submenu?: React.ReactNode;
  selected?: boolean;
};

export function DropdownItem({ value, disabled, className, onClick, submenu, selected }: DropdownItemProps) {
  const itemRef = useRef(null);
  const submenuRef = useRef(null);
  const [isSubmenuOpen, setIsSubmenuOpen] = useState(false);

  return (
    <li
      ref={itemRef}
      className={`${styles['dropdown-item']} ${className && className} hover:bg-primary-100 ${selected ? 'bg-primary text-white hover:text-black' : ''}`}
      onClick={() => {
        !disabled && onClick && onClick(value);
      }}
      onMouseEnter={() => setIsSubmenuOpen(true)}
      onMouseLeave={() => setIsSubmenuOpen(false)}
    >
      {value}
      {submenu && isSubmenuOpen && <DropdownSubmenuContainer ref={submenuRef}>{submenu}</DropdownSubmenuContainer>}
    </li>
  );
}

type DropdownSubmenuContainerProps = {
  children: ReactNode;
};

export const DropdownSubmenuContainer = React.forwardRef<HTMLDivElement, DropdownSubmenuContainerProps>(({ children }, ref) => {
  return (
    <div ref={ref} className="z-10 absolute bg-light rounded shadow w-44 left-[-80%] -translate-y-7">
      <ul className="text-sm text-secondary-700">{children}</ul>
    </div>
  );
});
